
from src.rest_requests.rest_request import Request as req
from src.steering.answer_parser import  CurrentWeatherAnswerParser, SearchWeatherAnswerParser,FutureWeatherAnswerParser
import json
class Question():
    def __init__(self):
        self.request=req()
        self.current_weather_parser = CurrentWeatherAnswerParser()
        self.search_weather_parser = SearchWeatherAnswerParser()
        self.future_weather_parser = FutureWeatherAnswerParser()

    def get_actual_weather(self):
        temp = self.request.get_current_weather().text
        temp = temp[5: -1]
        self.current_weather_parser.parse_current_weather(json.loads(temp))
        return self.current_weather_parser
    def get_search_weather_data(self):
        temp = self.request.get_search_weather_data().text
        self.search_weather_parser.parse_search_weather_data(json.loads(temp))
        return self.search_weather_parser
    def get_future_weather(self):
        temp = self.request.get_future_weather().text
        self.future_weather_parser.parse_future_weather(json.loads(temp))
        return self.future_weather_parser


if __name__=="__main__":
    q = Question()
    t1 = q.get_data(1)
    t2 = q.get_data(2)
    t3 = q.get_data(3)
    print(t1.temp)
    print(t2.temp)
    print(t3.temp)



import requests
class RequestExecutor():

    def execute_query(self,url,headers,querystring):
        return requests.request("GET", url, headers=headers, params=querystring)

if __name__ == "__main__":
    r=RequestExecutor()
    print(r.execute_query().text)





class CurrentWeatherAnswerParser():
    def __init__(self):
        self.temperature = None
        self.temp = None

    def parse_current_weather(self,answer):
        self.temp = answer
        self.temperature = self.temp.get("main").get("temp")

class SearchWeatherAnswerParser():
    def __init__(self):
        self.temp= None
        self.temperature = None
        self. temperature_max = None
        self.temperature_min = None

    def parse_search_weather_data(self,answer):
        self.temp = answer
        self.temperature = (self.temp.get("list")[0]).get("main").get("temp")
        self.temperature_min = (self.temp.get("list")[0]).get("main").get("temp_min")
        self.temperature_max = (self.temp.get("list")[0]).get("main").get("temp_max")

class FutureWeatherAnswerParser():
    def __init__(self):
        self.temp = None
        self.temperature_list = []

    def parse_future_weather(self,answer):
        self.temp = answer
        list = self.temp.get("list")

        size = len(list)
        for x in range(size):
            self.temperature_list.append(list[x].get("temp").get("day"))

if __name__=="__main__":
    pass




from src.rest_requests.rest_request_executor import RequestExecutor as re

class Request():
    def __init__(self):
        self.request_executor =re()
    def get_current_weather(self):
        url = "https://community-open-weather-map.p.rapidapi.com/weather"

        querystring = {"q": "London,uk", "lat": "0", "lon": "0", "callback": "test", "id": "2172797", "lang": "null",
                       "units": "imperial", "mode": "xml"}

        headers = {
            "X-RapidAPI-Host": "community-open-weather-map.p.rapidapi.com",
            "X-RapidAPI-Key": "ec4350f46cmshe3414fc29210337p1e4ac7jsnff32e507d3ab"
        }
        response = self.request_executor.execute_query(url,headers,querystring)
        return response
    def get_search_weather_data(self):
        url = "https://community-open-weather-map.p.rapidapi.com/find"

        querystring = {"q": "london", "cnt": "2", "mode": "null", "lon": "0", "type": "link, accurate", "lat": "0",
                       "units": "imperial, metric"}

        headers = {
            "X-RapidAPI-Host": "community-open-weather-map.p.rapidapi.com",
            "X-RapidAPI-Key": "ec4350f46cmshe3414fc29210337p1e4ac7jsnff32e507d3ab"
        }
        response = self.request_executor.execute_query(url,headers,querystring)
        return response
    def get_future_weather(self):
        url = "https://community-open-weather-map.p.rapidapi.com/forecast/daily"

        querystring = {"q": "san francisco,us", "lat": "35", "lon": "139", "cnt": "10", "units": "metric or imperial"}

        headers = {
            "X-RapidAPI-Host": "community-open-weather-map.p.rapidapi.com",
            "X-RapidAPI-Key": "ec4350f46cmshe3414fc29210337p1e4ac7jsnff32e507d3ab"
        }
        response = self.request_executor.execute_query(url,headers,querystring)
        return response



from distutils.core import setup

setup(
    # Application name:
    name="Weather rest library",

    # Version number (initial):
    version="1.0.2",

    # Application author details:
    author="Mateusz Urbańczyk",
    author_email="name@addr.ess",

    # Packages
    packages=["rest_requests","steering"],

    # Include additional files into the package
    include_package_data=True,

    # Details
    url="https://git.e-science.pl/murbanczyk_252808/murbanczyk252808_dpp_python_pip",

    #
    # license="LICENSE.txt",
    description="Useful towel-related stuff.",

    # long_description=open("README.txt").read(),

    # Dependent packages (distributions)
    install_requires=[
        "requests"
    ],
)